﻿Imports System.ComponentModel
Imports System.Net.NetworkInformation
Imports UrsTinyWebDBServer

Public Class frmLogActions
   Dim WithEvents WebDBServer As WebDBServer
   Dim Database As New JsonDictionaryDB
   Dim UrsTinyWebDBPort As Integer = 8082

   Private Sub Form1_Load(sender As Object, e As EventArgs) Handles MyBase.Load
      Control.CheckForIllegalCrossThreadCalls = False
      Database.Initialize()
      WebDBServer = New WebDBServer(Database)
   End Sub

   Private Sub CmdClear_Click(sender As Object, e As EventArgs) Handles CmdClear.Click
      TbxLog.Text = ""
   End Sub

   Private Sub AddLogItem(Text As String)
      If TbxLog.Text = "" Then
         TbxLog.Text = Text
      Else
         TbxLog.Text &= vbCrLf & Text
      End If

      If CbxScoll.Checked Then
         TbxLog.SelectionStart = TbxLog.Text.Length
         TbxLog.ScrollToCaret()
      End If
   End Sub

   Private Sub WebDBServer_ValueDelivered(Key As String, Value As String) Handles WebDBServer.ValueDelivered
      AddLogItem("Returned: " & Key & "=" & Value)
   End Sub

   Private Sub WebDBServer_ValueStored(Key As String, Value As String) Handles WebDBServer.ValueStored
      TbxLog.Text &= vbCrLf & "Stored: " & Key & "=" & Value
      TbxLog.SelectionStart = TbxLog.Text.Length
      TbxLog.ScrollToCaret()
   End Sub

   Private Sub WebDBServer_DBServerStarted() Handles WebDBServer.DBServerStarted
      AddLogItem("Service gestartet, IP-Adressen sind:")
      For Each NIC In NetworkInterface.GetAllNetworkInterfaces()
         If NIC.OperationalStatus = OperationalStatus.Up Then
            For Each ip As UnicastIPAddressInformation In NIC.GetIPProperties().UnicastAddresses
               If (ip.Address.AddressFamily = System.Net.Sockets.AddressFamily.InterNetwork) Then
                  AddLogItem("  " & ip.Address.ToString & ":" & UrsTinyWebDBPort & "   (" & NIC.Name & ")")
               End If
            Next
         End If
      Next
      LblState.Text = "Service ist aktiv"
      LblState.BackColor = Color.Green
      CmdStartStop.Text = "Service stoppen"
   End Sub

   Private Sub WebDBServer_DBServerStopped() Handles WebDBServer.DBServerStopped
      AddLogItem("Service gestoppt")
      LblState.Text = "Service ist gestoppt"
      LblState.BackColor = Color.Red
      CmdStartStop.Text = "Service starten"
   End Sub

   Private Sub WebDBServer_NotFound(ResourceName As String) Handles WebDBServer.NotFound
      AddLogItem("Ressource nicht gefunden" & ResourceName)
   End Sub

   Private Sub CmdStartStop_Click(sender As Object, e As EventArgs) Handles CmdStartStop.Click
      If WebDBServer.IsRunning Then
         WebDBServer.StopWebServer()
      Else
         WebDBServer.StartWebDBServer(UrsTinyWebDBPort)
      End If
   End Sub

   Private Sub LlbAbout_Click(sender As Object, e As EventArgs) Handles LlbAbout.Click
      Dim f As New AboutBox
      f.ShowDialog()
   End Sub

   Private Sub frmAdmin_Closing(sender As Object, e As CancelEventArgs) Handles Me.Closing
      If Database.IsDirty Then
         Database.Persist()
      End If
      WebDBServer.StopWebServer()
   End Sub
End Class
